@@ -64,17 +64,17 @@ class ConfusionMatrixWidget:
         with self.accuracy_plt:
             self.accuracy_plt.clear_output(wait=True)
             self.__generate_cnf(self.t_widget.value)
-            tp, fp, fn, tn = self._cnf_matrix.ravel()
+            tn, fp, fn, tp = self._cnf_matrix.ravel()
             score = round(sum([tp + tn]) / sum([tp, fp, fn, tn]), 2)
             s = r"""
                 \text{Accuracy} = \dfrac{
-                    \color{orange}{$TP}
-                    + \color{purple}{$TN}
+                    \color{purple}{$TP}
+                    + \color{orange}{$TN}
                 }{
-                    \color{orange}{$TP}
-                    + \color{red}{$FP}
-                    + \color{purple}{$TN}
+                    \color{purple}{$TP}
                     + \color{blue}{$FN}
+                    + \color{orange}{$TN}
+                    + \color{red}{$FP}
                 } = $SCORE
             """
             temp = Template(s).substitute(
@@ -86,13 +86,13 @@ class ConfusionMatrixWidget:
         with self.precision_plt:
             self.precision_plt.clear_output(wait=True)
             self.__generate_cnf(self.t_widget.value)
-            tp, fp, _, _ = self._cnf_matrix.ravel()
+            _, fp, _, tp = self._cnf_matrix.ravel()
             score = round(tp / (tp + fp), 2)
             s = r"""
                 \text{Precision} = \dfrac{
-                    \color{orange}{$TP}
+                    \color{purple}{$TP}
                 }{
-                    \color{orange}{$TP}
+                    \color{purple}{$TP}
                     + \color{red}{$FP}
                 } = $SCORE
             """
@@ -103,13 +103,13 @@ class ConfusionMatrixWidget:
         with self.recall_plt:
             self.recall_plt.clear_output(wait=True)
             self.__generate_cnf(self.t_widget.value)
-            tp, _, fn, _ = self._cnf_matrix.ravel()
+            _, _, fn, tp = self._cnf_matrix.ravel()
             score = round(tp / (tp + fn), 2)
             s = r"""
                 \text{Recall} = \dfrac{
-                    \color{orange}{$TP}
+                    \color{purple}{$TP}
                 }{
-                    \color{orange}{$TP}
+                    \color{purple}{$TP}
                     + \color{blue}{$FN}
                 } = $SCORE
             """
@@ -176,13 +176,13 @@ class ConfusionMatrixWidget:
             layout=widgets.Layout(height="300px", width="300px")
         )
         self.accuracy_plt = widgets.Output(
-            layout=widgets.Layout(height="80px", width="300px")
+            layout=widgets.Layout(height="80px", width="400px")
         )
         self.precision_plt = widgets.Output(
-            layout=widgets.Layout(height="80px", width="300px")
+            layout=widgets.Layout(height="80px", width="400px")
         )
         self.recall_plt = widgets.Output(
-            layout=widgets.Layout(height="80px", width="300px")
+            layout=widgets.Layout(height="80px", width="400px")
         )
         self.t_widget = widgets.FloatSlider(
             value=0.5, min=0.0, max=1, step=0.1, description="Threshold:"
